==> prestashop_1.4.0.2.zip: prestashop/modules/moneybookers/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{moneybookers}prestashop>confirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Su pedido en';
$_MODULE['<{moneybookers}prestashop>confirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'se ha completado.';
$_MODULE['<{moneybookers}prestashop>confirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Su pedido será enviado tan pronto como sea posible.';
$_MODULE['<{moneybookers}prestashop>confirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Para cualquier duda o para más información, póngase en contacto con nuestro servicio de atención al cliente';
$_MODULE['<{moneybookers}prestashop>confirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = ' ';
$_MODULE['<{moneybookers}prestashop>confirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Nos hemos dado cuenta de un problema con su pedido.  Si usted piensa que esto es un error, puede contactar con nuestro';
$_MODULE['<{moneybookers}prestashop>moneybookers-currency-error_6484c945379d81c37ac734c9768605cf'] = 'rnNo puede efectuar el pago de su pedido con Moneybookers ya que su divisa actual no está autorizada. Por favor, elija otra.';
$_MODULE['<{moneybookers}prestashop>moneybookers-form_25065e3ef9274f9b0e3088340f6d79e6'] = 'Pagar con tarjeta de crédito';
$_MODULE['<{moneybookers}prestashop>moneybookers-form_2cc66b7b26e92326afa76a021442330e'] = 'Pagar con el monedero electrónico MoneyBookers (eWallet)';
$_MODULE['<{moneybookers}prestashop>moneybookers_6861a58e2be4956b3f2fd6420fe6c28c'] = 'Moneybookers';
$_MODULE['<{moneybookers}prestashop>moneybookers_07bf11ff6eaf27b8aa91f42d7fb4200c'] = 'Acepta pagos por Moneybookers';
$_MODULE['<{moneybookers}prestashop>moneybookers_fa214007826415a21a8456e3e09f999d'] = '¿Está seguro de que quiere eliminar sus datos?';
$_MODULE['<{moneybookers}prestashop>moneybookers_2d2eca55f12f72b2e1d753b7deadd9f5'] = 'Actualmente utiliza la dirección por defecto del módulo Moneybookers. Debe utilizar sus parámetros.';
$_MODULE['<{moneybookers}prestashop>moneybookers_bd65b912e0152f62629b6afeaa8398f4'] = 'Imposible contactar con el servidor de activación, por favor inténtelo más tarde';
$_MODULE['<{moneybookers}prestashop>moneybookers_c9f3e0397a1b070092ab4f0bf046fd4a'] = 'Error durante la validación de la cuenta, su correo electrónico podría estar equivocado';
$_MODULE['<{moneybookers}prestashop>moneybookers_74b8a559fcedbb491aba11dd10610b5f'] = 'E-mail activado con éxito, ahora puede validar su palabra secreta';
$_MODULE['<{moneybookers}prestashop>moneybookers_7b1b775b5b6d8ea22cc69affd4bb162c'] = 'El campo email es obligatorio';
$_MODULE['<{moneybookers}prestashop>moneybookers_214186253fc29d921411c68ac88d942e'] = 'Error durante la validación de la palabra secreta, ha sobrepasado el número máximo de intentos (3 por hora)';
$_MODULE['<{moneybookers}prestashop>moneybookers_ccd8489089bfa25fffbc82674bf6b8b5'] = 'Error durante la validación de la palabra secreta, su palabra secreta podría estar equivocada';
$_MODULE['<{moneybookers}prestashop>moneybookers_7d2d842e3d3628e5fedb1899e710fb44'] = 'Cuenta activada correctamente, la palabra secreta es correcta';
$_MODULE['<{moneybookers}prestashop>moneybookers_c193f11bec44b77c0f60ddf50bc30cc8'] = 'El campo palabra secreta es obligatorio';
$_MODULE['<{moneybookers}prestashop>moneybookers_a9dd80641753cafc9c967e317ba92a28'] = 'Sobre Moneybookers';
$_MODULE['<{moneybookers}prestashop>moneybookers_6b9a842511dd894375882f964ee626e8'] = 'Moneybookers es uno de los sistemas de pago en línea más grandes de Europa  y se sitúa entre los principales proveedores del mundo de eWallet, con más de 14 millones de titulares de cuentas. El sencillo eWallet permite a cualquier cliente pagar en línea de manera cómoda y segura sin revelar datos financieros personales, y también le permite enviar y recibir transferencias de dinero de forma rentable, usando simplemente una dirección de correo electrónico. ';
$_MODULE['<{moneybookers}prestashop>moneybookers_e545ce3f77ed798605ba3dc853e7e040'] = 'Moneybookers es una de los sistemas de pago en línea más importantes de Europa, propone más de 80 opciones de pago en más de 200 países en todo el mundo. Más de 60 000 comerciantes, como eBay.com, Skype et Thomas Cook utilizan ya Moneybookers. ';
$_MODULE['<{moneybookers}prestashop>moneybookers_04a0e2e14bfc47151f158db3c1b03661'] = 'Moneybookers fue fundado en 2001 en Londres y está regulado por la Autoridad de Servicios Financieros del Reino Unido.';
$_MODULE['<{moneybookers}prestashop>moneybookers_bf31254706bb3f750e7f46cabea4e73a'] = 'Apertura de cuenta';
$_MODULE['<{moneybookers}prestashop>moneybookers_41992c760318e60740f7a9b2819af191'] = 'Comience por abrir';
$_MODULE['<{moneybookers}prestashop>moneybookers_c0302a6fbca061af831bc12f06cadb2f'] = 'una cuenta gratis';
$_MODULE['<{moneybookers}prestashop>moneybookers_d5ac14a97f40e4aadd7eb202f7c124b1'] = 'con Moneybookers:';
$_MODULE['<{moneybookers}prestashop>moneybookers_b0e8c8326985417a5efdd6649f02e385'] = 'Gracias a la asociación entre PrestaShop y Moneybookers,';
$_MODULE['<{moneybookers}prestashop>moneybookers_d5086eeb1bc1994c5abf945fd79d4246'] = '¡obtendrá una tasa de comisión preferencial!';
$_MODULE['<{moneybookers}prestashop>moneybookers_3513f0ecb96b6c959454534578ee1404'] = 'A continuación, haga clic aquí:';
$_MODULE['<{moneybookers}prestashop>moneybookers_64d37ad3bf2f0aee7c8a321321c7e9d9'] = 'Ya tengo una cuenta en Moneybookers';
$_MODULE['<{moneybookers}prestashop>moneybookers_f284fe53995a4cc2e1e099cb1e511ec8'] = 'Validación de cuenta';
$_MODULE['<{moneybookers}prestashop>moneybookers_c5093f03229416cc06a625654429d7f2'] = 'Su cuenta ha sido activada';
$_MODULE['<{moneybookers}prestashop>moneybookers_bd8df5ae85f76ba759fa979ada8566ea'] = 'Necesita';
$_MODULE['<{moneybookers}prestashop>moneybookers_558b256c79bbcf473cc7347ec1ca9d54'] = 'validar su cuenta';
$_MODULE['<{moneybookers}prestashop>moneybookers_32f1d1c0ced87af44fbf6e5ca6cd6962'] = 'por favor, escriba la dirección de correo electrónico que utilizó para abrir su cuenta de Moneybookers:';
$_MODULE['<{moneybookers}prestashop>moneybookers_71b5b9efebe9c2f73fad6dd1849b4312'] = 'Validar mi cuenta';
$_MODULE['<{moneybookers}prestashop>moneybookers_6f263adfd92cecceb6d26d13f068d16b'] = 'Si necesita ayuda, lea la activación manual';
$_MODULE['<{moneybookers}prestashop>moneybookers_0b65457508cf73c9ed8c96f56b8910ce'] = 'Validación de la palabra secreta';
$_MODULE['<{moneybookers}prestashop>moneybookers_e44efbda9396a5641d730f0ac4866e52'] = 'Su palabra secreta ha sido activada';
$_MODULE['<{moneybookers}prestashop>moneybookers_7360d9333103eec04f2d91fa513a1f46'] = 'valide su palabra secreta';
$_MODULE['<{moneybookers}prestashop>moneybookers_317b5a6ce749b57e5fb7f59ce67bbeaa'] = 'por favor, escriba la misma palabra secreta que introdujo en su cuenta en Moneybookers:';
$_MODULE['<{moneybookers}prestashop>moneybookers_22f2d26badcc700d11b93f57dc96d386'] = 'Valide mi palabra secreta';
$_MODULE['<{moneybookers}prestashop>moneybookers_da717f0f47832f3a367fb0e7049ccf6f'] = 'Marque los';
$_MODULE['<{moneybookers}prestashop>moneybookers_cf189f988336fea71f05010d1525be9c'] = 'métodos de pago internacionales';
$_MODULE['<{moneybookers}prestashop>moneybookers_f0d9c5137b399ee849597db13aa10431'] = 'que desea activar:';
$_MODULE['<{moneybookers}prestashop>moneybookers_b119e159b6f2d56f8ddead2af4561f38'] = 'métodos de pago locales';
$_MODULE['<{moneybookers}prestashop>moneybookers_542725fe3d40df98822aa76779462d44'] = 'Parámetros y formas de pago';
$_MODULE['<{moneybookers}prestashop>moneybookers_87337b7475d1287ff99aaa30446b3bb7'] = 'Página que se muestra si error de pago:';
$_MODULE['<{moneybookers}prestashop>moneybookers_ab67f0d68dd6f5cb407e04abacd06120'] = 'Ocultar el formulario de acceso a la página de Moneybookers';
$_MODULE['<{moneybookers}prestashop>moneybookers_554fd8768f165251646ce21ba4998208'] = 'Modo de visualización:';
$_MODULE['<{moneybookers}prestashop>moneybookers_a190bc880b04cf478e0370d1b315a5a3'] = 'Todos los logos en un bloque';
$_MODULE['<{moneybookers}prestashop>moneybookers_852d04b5f455aaf5264e9a8c561ced71'] = 'Un bloque para cada logo';
$_MODULE['<{moneybookers}prestashop>moneybookers_d4dccb8ca2dac4e53c01bd9954755332'] = 'Guardar los parámetros';
$_MODULE['<{moneybookers}prestashop>moneybookers_27266fe4d37bf06589c7c6dbf2d5c067'] = 'Pagar por';

==> prestashop_1.4.0.3.zip: prestashop/modules/moneybookers/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{moneybookers}prestashop>confirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Su pedido en';
$_MODULE['<{moneybookers}prestashop>confirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'se ha completado.';
$_MODULE['<{moneybookers}prestashop>confirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Su pedido será enviado tan pronto como sea posible.';
$_MODULE['<{moneybookers}prestashop>confirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Para cualquier duda o para más información, póngase en contacto con nuestro servicio de atención al cliente';
$_MODULE['<{moneybookers}prestashop>confirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = ' ';
$_MODULE['<{moneybookers}prestashop>confirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Nos hemos dado cuenta de un problema con su pedido.  Si usted piensa que esto es un error, puede contactar con nuestro';
$_MODULE['<{moneybookers}prestashop>moneybookers-currency-error_6484c945379d81c37ac734c9768605cf'] = 'rnNo puede efectuar el pago de su pedido con Moneybookers ya que su divisa actual no está autorizada. Por favor, elija otra.';
$_MODULE['<{moneybookers}prestashop>moneybookers-form_25065e3ef9274f9b0e3088340f6d79e6'] = 'Pagar con tarjeta de crédito';
$_MODULE['<{moneybookers}prestashop>moneybookers-form_2cc66b7b26e92326afa76a021442330e'] = 'Pagar con el monedero electrónico MoneyBookers (eWallet)';
$_MODULE['<{moneybookers}prestashop>moneybookers_6861a58e2be4956b3f2fd6420fe6c28c'] = 'Moneybookers';
$_MODULE['<{moneybookers}prestashop>moneybookers_07bf11ff6eaf27b8aa91f42d7fb4200c'] = 'Acepta pagos por Moneybookers';
$_MODULE['<{moneybookers}prestashop>moneybookers_fa214007826415a21a8456e3e09f999d'] = '¿Está seguro de que quiere eliminar sus datos?';
$_MODULE['<{moneybookers}prestashop>moneybookers_2d2eca55f12f72b2e1d753b7deadd9f5'] = 'Actualmente utiliza la dirección por defecto del módulo Moneybookers. Debe utilizar sus parámetros.';
$_MODULE['<{moneybookers}prestashop>moneybookers_bd65b912e0152f62629b6afeaa8398f4'] = 'Imposible contactar con el servidor de activación, por favor inténtelo más tarde';
$_MODULE['<{moneybookers}prestashop>moneybookers_c9f3e0397a1b070092ab4f0bf046fd4a'] = 'Error durante la validación de la cuenta, su correo electrónico podría estar equivocado';
$_MODULE['<{moneybookers}prestashop>moneybookers_74b8a559fcedbb491aba11dd10610b5f'] = 'E-mail activado con éxito, ahora puede validar su palabra secreta';
$_MODULE['<{moneybookers}prestashop>moneybookers_7b1b775b5b6d8ea22cc69affd4bb162c'] = 'El campo email es obligatorio';
$_MODULE['<{moneybookers}prestashop>moneybookers_214186253fc29d921411c68ac88d942e'] = 'Error durante la validación de la palabra secreta, ha sobrepasado el número máximo de intentos (3 por hora)';
$_MODULE['<{moneybookers}prestashop>moneybookers_ccd8489089bfa25fffbc82674bf6b8b5'] = 'Error durante la validación de la palabra secreta, su palabra secreta podría estar equivocada';
$_MODULE['<{moneybookers}prestashop>moneybookers_7d2d842e3d3628e5fedb1899e710fb44'] = 'Cuenta activada correctamente, la palabra secreta es correcta';
$_MODULE['<{moneybookers}prestashop>moneybookers_c193f11bec44b77c0f60ddf50bc30cc8'] = 'El campo palabra secreta es obligatorio';
$_MODULE['<{moneybookers}prestashop>moneybookers_a9dd80641753cafc9c967e317ba92a28'] = 'Sobre Moneybookers';
$_MODULE['<{moneybookers}prestashop>moneybookers_6b9a842511dd894375882f964ee626e8'] = 'Moneybookers es uno de los sistemas de pago en línea más grandes de Europa  y se sitúa entre los principales proveedores del mundo de eWallet, con más de 14 millones de titulares de cuentas. El sencillo eWallet permite a cualquier cliente pagar en línea de manera cómoda y segura sin revelar datos financieros personales, y también le permite enviar y recibir transferencias de dinero de forma rentable, usando simplemente una dirección de correo electrónico. ';
$_MODULE['<{moneybookers}prestashop>moneybookers_e7b1131d3aa46eff3167113b15065702'] = 'Moneybookers es uno de los sistemas de pago en línea más importantes de Europa. Propone más de 80 opciones de pago en más de 200 países en todo el mundo. Actualmente más de 60 000 sitios utilizan esta solución, entre otros eBay.com, Skype y Thomas Cook';
$_MODULE['<{moneybookers}prestashop>moneybookers_04a0e2e14bfc47151f158db3c1b03661'] = 'Moneybookers fue fundado en 2001 en Londres y está regulado por la Autoridad de Servicios Financieros del Reino Unido.';
$_MODULE['<{moneybookers}prestashop>moneybookers_bf31254706bb3f750e7f46cabea4e73a'] = 'Abrir una cuenta';
$_MODULE['<{moneybookers}prestashop>moneybookers_41992c760318e60740f7a9b2819af191'] = 'Comience por abrir';
$_MODULE['<{moneybookers}prestashop>moneybookers_c0302a6fbca061af831bc12f06cadb2f'] = 'una cuenta gratis';
$_MODULE['<{moneybookers}prestashop>moneybookers_d5ac14a97f40e4aadd7eb202f7c124b1'] = 'con Moneybookers:';
$_MODULE['<{moneybookers}prestashop>moneybookers_b0e8c8326985417a5efdd6649f02e385'] = 'Gracias a la asociación entre PrestaShop y Moneybookers,';
$_MODULE['<{moneybookers}prestashop>moneybookers_d5086eeb1bc1994c5abf945fd79d4246'] = '¡obtendrá una tasa de comisión preferencial!';
$_MODULE['<{moneybookers}prestashop>moneybookers_3513f0ecb96b6c959454534578ee1404'] = 'A continuación, haga clic aquí:';
$_MODULE['<{moneybookers}prestashop>moneybookers_64d37ad3bf2f0aee7c8a321321c7e9d9'] = 'Ya tengo una cuenta en Moneybookers';
$_MODULE['<{moneybookers}prestashop>moneybookers_f284fe53995a4cc2e1e099cb1e511ec8'] = 'Validación de cuenta';
$_MODULE['<{moneybookers}prestashop>moneybookers_c5093f03229416cc06a625654429d7f2'] = 'Su cuenta ha sido activada';
$_MODULE['<{moneybookers}prestashop>moneybookers_bd8df5ae85f76ba759fa979ada8566ea'] = 'Necesita';
$_MODULE['<{moneybookers}prestashop>moneybookers_558b256c79bbcf473cc7347ec1ca9d54'] = 'validar su cuenta';
$_MODULE['<{moneybookers}prestashop>moneybookers_32f1d1c0ced87af44fbf6e5ca6cd6962'] = 'por favor, escriba la dirección de correo electrónico que utilizó para abrir su cuenta de Moneybookers:';
$_MODULE['<{moneybookers}prestashop>moneybookers_71b5b9efebe9c2f73fad6dd1849b4312'] = 'Validar mi cuenta';
$_MODULE['<{moneybookers}prestashop>moneybookers_6f263adfd92cecceb6d26d13f068d16b'] = 'Si necesita ayuda, lea la activación manual';
$_MODULE['<{moneybookers}prestashop>moneybookers_0b65457508cf73c9ed8c96f56b8910ce'] = 'Validación de la palabra secreta';
$_MODULE['<{moneybookers}prestashop>moneybookers_e44efbda9396a5641d730f0ac4866e52'] = 'Su palabra secreta ha sido activada';
$_MODULE['<{moneybookers}prestashop>moneybookers_7360d9333103eec04f2d91fa513a1f46'] = 'valide su palabra secreta';
$_MODULE['<{moneybookers}prestashop>moneybookers_317b5a6ce749b57e5fb7f59ce67bbeaa'] = 'por favor, escriba la misma palabra secreta que introdujo en su cuenta en Moneybookers:';
$_MODULE['<{moneybookers}prestashop>moneybookers_22f2d26badcc700d11b93f57dc96d386'] = 'Valide mi palabra secreta';
$_MODULE['<{moneybookers}prestashop>moneybookers_da717f0f47832f3a367fb0e7049ccf6f'] = 'Marque los';
$_MODULE['<{moneybookers}prestashop>moneybookers_cf189f988336fea71f05010d1525be9c'] = 'métodos de pago internacionales';
$_MODULE['<{moneybookers}prestashop>moneybookers_f0d9c5137b399ee849597db13aa10431'] = 'que desea activar:';
$_MODULE['<{moneybookers}prestashop>moneybookers_b119e159b6f2d56f8ddead2af4561f38'] = 'métodos de pago locales';
$_MODULE['<{moneybookers}prestashop>moneybookers_542725fe3d40df98822aa76779462d44'] = 'Parámetros y formas de pago';
$_MODULE['<{moneybookers}prestashop>moneybookers_87337b7475d1287ff99aaa30446b3bb7'] = 'Página que se muestra si error de pago:';
$_MODULE['<{moneybookers}prestashop>moneybookers_ab67f0d68dd6f5cb407e04abacd06120'] = 'Ocultar el formulario de acceso a la página de Moneybookers';
$_MODULE['<{moneybookers}prestashop>moneybookers_554fd8768f165251646ce21ba4998208'] = 'Modo de visualización:';
$_MODULE['<{moneybookers}prestashop>moneybookers_a190bc880b04cf478e0370d1b315a5a3'] = 'Todos los logos en un bloque';
$_MODULE['<{moneybookers}prestashop>moneybookers_852d04b5f455aaf5264e9a8c561ced71'] = 'Un bloque para cada logo';
$_MODULE['<{moneybookers}prestashop>moneybookers_d4dccb8ca2dac4e53c01bd9954755332'] = 'Guardar los parámetros';
$_MODULE['<{moneybookers}prestashop>moneybookers_27266fe4d37bf06589c7c6dbf2d5c067'] = 'Pagar por';
